@@ -80,6 +80,24 @@ def add_images_to_existing_project(session, projnumber):
                     "parent": existing_project
                 })
 
+        moving_images = [i for i in existing_project['children']
+                         if "MovingImage" in i["name"]]
+        num_existing_moving = 0
+        if moving_images is not None and len(moving_images) > 0:
+            moving_folder = moving_images[0]
+            num_existing_moving = len(moving_folder["children"])
+            print(
+                f'{existing_project["name"]} already has {num_existing_moving} moving images')
+        else:
+            print(
+                f"{existing_project['name']} has no moving images, let's create a folder for them!")
+            moving_folder = session.create(
+                "Folder",
+                {
+                    "name": f"{projnumber}_MovingImages",
+                    "parent": existing_project
+                })
+
         while True:
             try:
                 additional_ints = int(input("Enter amount of additional INT shots: "))
@@ -112,6 +130,25 @@ def add_images_to_existing_project(session, projnumber):
                 ext_artist = select_artist(project_team, users, "Select EXT artist")
             else:
                 ext_artist = project_team[0]
+
+        while True:
+            try:
+                additional_moving = int(
+                    input("Enter amount of additional MovingImage shots: "))
+            except ValueError:
+                print("Sorry, I didn't understand that? Did you type a number?")
+                continue
+            else:
+                print(f"Number of addtional MovingImage: {additional_moving}")
+                break
+
+        if additional_moving > 0:
+            if len(project_team) > 1:
+                moving_artist = select_artist(
+                    project_team, users, "Select MovingImage artist")
+            else:
+                moving_artist = project_team[0]
+        # interiors
         num_int = num_exist_int + additional_ints
         for i in range(num_exist_int, num_exist_int + additional_ints):
             shot = shotnumber_to_letter(i)
@@ -132,6 +169,7 @@ def add_images_to_existing_project(session, projnumber):
                                "resource": int_artist,
                                "type": "assignment"}
                                )
+        # exteriors
         num_ext = num_existing_ext + additional_exteriors
         for i in range(num_existing_ext, num_existing_ext + additional_exteriors):
             shot = shotnumber_to_letter(i)
@@ -154,6 +192,27 @@ def add_images_to_existing_project(session, projnumber):
                                "type": "assignment"}
                                )
 
+        num_moving = num_existing_moving + additional_moving
+        for i in range(num_exist_int, num_exist_int + additional_ints):
+            shot = shotnumber_to_letter(i)
+            print(f"📸 MovingImage {shot} for {moving_artist['username']}")
+            moving_shot_name = f"{projnumber}_MovingImage_{shot}"
+            moving_shot = session.create("Image", {
+                "name": moving_shot_name,
+                "parent": moving_folder}
+            )
+            for task_type in [t["task_type"] for t in image_template["items"]]:
+                task = session.create("Task", {
+                                      "name": task_type["name"],
+                                      "type": task_type,
+                                      "parent": moving_shot}
+                                      )
+                session.create("Appointment", {
+                               "context": task,
+                               "resource": moving_artist,
+                               "type": "assignment"}
+                               )
+
         if num_int == 0:
             desc = f"{num_ext} EXT"
         elif num_ext == 0:
